package sdk

type GetRefundListRes struct {
	commonRes
	Data struct {
		Count int          `json:"count"`
		Data  []RefundList `json:"data"`
	} `json:"data"`
}
type RefundList struct {
	Id           int    `json:"id"`
	RefundSn     string `json:"refund_sn"`
	SellerId     int    `json:"seller_id"`
	GoodsOrderSn string `json:"goods_order_sn"`
	Title        string `json:"title"`
	RefundType   int    `json:"refund_type"`
	Status       int    `json:"status"`
	Reason       int    `json:"reason"`
	CreatedTime  int    `json:"created_time"`
	OperateTime  int    `json:"operate_time"`
	EndTime      int    `json:"end_time"`
	Deadline     int    `json:"deadline"`
	OrderSn      string `json:"order_sn"`
	Thumb        string `json:"thumb"`
	Mobile       string `json:"mobile"`
	GoodsStatus  int    `json:"goods_status"`
	CloseReason  int    `json:"close_reason"`
	ChannelName  string `json:"channel_name"`
	ChannelId    int    `json:"channel_id"`
}
type OrderRefundCheckReasonModel struct {
	Code    string `json:"code"`
	Content string `json:"content"`
}

//售后返回数据模型
type OrderRefundCheckModel struct {
	Code    int    `json:"code"`
	Content string `json:"content"`
}

//售后检测返回
type OrderRefundCheckRes struct {
	commonRes
	Data struct {
		ReasonList     []*OrderRefundCheckReasonModel `json:"reason_list"`
		ServiceType    []*OrderRefundCheckModel       `json:"service_type"`
		OrderSn        string                         `json:"order_sn"`
		MaxRefundMoney int                            `json:"max_refund_money"`
	} `json:"data"`
}

//创建售后订单
type CreateRefundOrderRes struct {
	commonRes
	Data struct {
		RefundOrderSn string `json:"refund_order_sn"`
	} `json:"data"`
}

//创建售后订单
type RefundOrderInfoRes struct {
	commonRes
	Data OrderRefundInfo `json:"data"`
}

//售后详情信息（包含售后商品订单信息以及售后历史）
type OrderRefundInfo struct {
	OrderRefund struct {
		*StOrderRefund
		DeadlineHour   int                   `json:"dead_line_hour"`   //剩余处理时间 时
		DeadlineMinute int                   `json:"dead_line_minute"` //剩余处理时间 分
		ImgsArr        []string              `json:"imgs_arr"`
		ReturnInfo     *StOrderRefundExpress `json:"return_info"`
	} `json:"order_refund"` //售后单信息
	OrderGoods     *StOrderGoods `json:"order_goods"` //商品订单信息
	OrderConsignee struct {
		RealName string `orm:"real_name"       json:"real_name"` //姓名
		Mobile   string `orm:"mobile"          json:"mobile"`    //手机号
		Provice  string `orm:"provice"         json:"provice"`   //省
		City     string `orm:"city"            json:"city"`      //市
		District string `orm:"district"        json:"district"`  //区县
		Street   string `orm:"street"          json:"street"`    //街道
		Address  string `orm:"address"         json:"address"`   //详细地址
	} `json:"order_consignee"` //买家信息
	OrderRefundHistory []*RefundHistory `json:"order_refund_history"` //当前商品订单的售后历史记录
}
type StOrderRefund struct {
	Id               int    `orm:"id,primary"         json:"id"`                 //
	RefundSn         string `orm:"refund_sn"          json:"refund_sn"`          // 退款单号
	SellerId         int    `orm:"seller_id"          json:"seller_id"`          // 商户Id
	GoodsOrderSn     string `orm:"goods_order_sn"     json:"goods_order_sn"`     // 商品订单号
	GoodsTotal       int    `orm:"goods_total"        json:"goods_total"`        // 退货数量
	RefundType       int    `orm:"refund_type"        json:"refund_type"`        // 退款类型 1仅退款 2退货退款
	Status           int    `orm:"status"             json:"status"`             // 退款状态-1关闭1待审核2待退货3待收货5已完成
	Reason           int    `orm:"reason"             json:"reason"`             // 申请退款原因 1 协商一致退款 2 质量问题 3 物流问题 4 假冒品牌 5 少件/漏发/破损/污渍  6 7天无理由 7 拍错/多拍/不想要 8  其他
	Content          string `orm:"content"            json:"content"`            // 退款内容
	Price            int    `orm:"price"              json:"price"`              // 商品金额 单位为分
	OrderPrice       int    `orm:"order_price"        json:"order_price"`        // 订单金额 单位为分不要
	ApplyPrice       int    `orm:"apply_price"        json:"apply_price"`        // 申请金额 单位为分
	Images           string `orm:"images"             json:"images"`             // 退款图片
	CreatedTime      int    `orm:"created_time"       json:"created_time"`       // 售后申请时间
	Reply            string `orm:"reply"              json:"reply"`              // 回复信息
	RejectReason     string `orm:"reject_reason"      json:"reject_reason"`      // 如果商家拒绝售后请求，驳回原因
	RefundAddress    string `orm:"refund_address"     json:"refund_address"`     // 商品退回地址
	Remark           string `orm:"remark"             json:"remark"`             // 系统备注
	OperateTime      int    `orm:"operate_time"       json:"operate_time"`       //
	EndTime          int    `orm:"end_time"           json:"end_time"`           // 完成时间
	CloseReason      int    `orm:"close_reason"       json:"close_reason"`       // 售后关闭原因： 1卖家拒绝退款、退货退款 2卖家拒收拒绝退款 3买家超时未退货自动关闭   6买家取消
	IsIntervene      int    `orm:"is_intervene"       json:"is_intervene"`       // 是否介入  0 否 1 是
	InterveneUser    string `orm:"intervene_user"     json:"intervene_user"`     // 介入人
	InterveneResult  string `orm:"intervene_result"   json:"intervene_result"`   // 接入处理结果
	InterveneTime    int    `orm:"intervene_time"     json:"intervene_time"`     // 介入处理时间
	InterveneRemark  string `orm:"intervene_remark"   json:"intervene_remark"`   // 介入备注
	AutoRefundReason int    `orm:"auto_refund_reason" json:"auto_refund_reason"` // 自动操作原因 1.商家超时未处理自动退款 2.商家超时未处理自动同意退货退款 3.商家超时未处理退货退款自动退款 4.买家超时未回传物流自动关闭
	ChannelId        int    `orm:"channel_id"         json:"channel_id"`         // 渠道id
	SiteId           int    `orm:"site_id"            json:"site_id"`            // 站点id(paasid)
}
type StOrderRefundExpress struct {
	Id                 int    `orm:"id,primary"           json:"id"`                   //
	OrderRefundId      int    `orm:"order_refund_id"      json:"order_refund_id"`      // 售后订单Id
	ExpressCompanyName string `orm:"express_company_name" json:"express_company_name"` // 物流公司名称
	ExpressSn          string `orm:"express_sn"           json:"express_sn"`           // 物流单号
	ExpressCode        string `orm:"express_code"         json:"express_code"`         // 物流公司代码
	CreatedTime        int    `orm:"created_time"         json:"created_time"`         // 创建时间
	UpdatedTime        int    `orm:"updated_time"         json:"updated_time"`         // 更新时间
	Description        string `orm:"description"          json:"description"`          // 描述说明
	Imgs               string `orm:"imgs"                 json:"imgs"`                 // 图片
}

type RefundHistory struct {
	Id               int      `orm:"id,primary"         json:"id"`                 //
	RefundSn         string   `orm:"refund_sn"          json:"refund_sn"`          // 退款单号
	SellerId         int      `orm:"seller_id"          json:"seller_id"`          // 商户Id
	GoodsOrderSn     string   `orm:"goods_order_sn"     json:"goods_order_sn"`     // 商品订单号
	GoodsTotal       int      `orm:"goods_total"        json:"goods_total"`        // 退货数量
	RefundType       int      `orm:"refund_type"        json:"refund_type"`        // 退款类型 1仅退款 2退货退款
	Status           int      `orm:"status"             json:"status"`             // 退款状态-1关闭1待审核2待退货3待收货5已完成
	Reason           int      `orm:"reason"             json:"reason"`             // 申请退款原因 1 其他 2 漏发 3 协商一致 4 质量不符
	Content          string   `orm:"content"            json:"content"`            // 退款内容
	Price            int      `orm:"price"              json:"price"`              // 商品金额 单位为分
	OrderPrice       int      `orm:"order_price"        json:"order_price"`        // 订单金额 单位为分不要
	ApplyPrice       int      `orm:"apply_price"        json:"apply_price"`        // 申请金额 单位为分
	Images           string   `orm:"images"             json:"images"`             // 退款图片
	CreatedTime      int      `orm:"created_time"       json:"created_time"`       // 售后申请时间
	Reply            string   `orm:"reply"              json:"reply"`              // 回复信息
	RejectReason     string   `orm:"reject_reason"      json:"reject_reason"`      // 如果商家拒绝售后请求，驳回原因
	RefundAddress    string   `orm:"refund_address"     json:"refund_address"`     // 商品退回地址
	Remark           string   `orm:"remark"             json:"remark"`             // 系统备注
	OperateTime      int      `orm:"operate_time"       json:"operate_time"`       //
	EndTime          int      `orm:"end_time"           json:"end_time"`           // 完成时间
	CloseReason      int      `orm:"close_reason"       json:"close_reason"`       // 售后关闭原因： 1卖家拒绝退款、退货退款 2卖家拒收拒绝退款 3买家超时未退货自动关闭 4卖家超时未处理自动退款  5卖家超时未处理自动退货退款  6买家取消
	IsIntervene      int      `orm:"is_intervene"       json:"is_intervene"`       // 是否介入  0 否 1 是
	InterveneUser    string   `orm:"intervene_user"     json:"intervene_user"`     // 介入人
	InterveneResult  string   `orm:"intervene_result"   json:"intervene_result"`   // 接入处理结果
	InterveneTime    int      `orm:"intervene_time"     json:"intervene_time"`     // 介入处理时间
	InterveneRemark  string   `orm:"intervene_remark"   json:"intervene_remark"`   // 介入备注
	AutoRefundReason string   `orm:"auto_refund_reason" json:"auto_refund_reason"` // 自动退款原因
	ImgsArr          []string `json:"imgs_arr"`
}
type AddRefundAddressRes struct {
	commonRes
	Data struct {
		Id int `json:"id"`
	} `json:"data"`
}
type GetRefundAddressListRes struct {
	commonRes
	Data struct {
		Count int                 `json:"count"`
		List  []RefundAddressList `json:"list"`
	} `json:"data"`
}
type RefundAddressList struct {
	Address      string `json:"address"`
	CityId       int    `json:"city_id"`
	CityName     string `json:"city_name"`
	CreatedTime  int    `json:"created_time"`
	DistrictId   int    `json:"district_id"`
	DistrictName string `json:"district_name"`
	Id           int    `json:"id"`
	Info         string `json:"info"`
	IsDefault    int    `json:"is_default"`
	IsDel        int    `json:"is_del"`
	Mobile       string `json:"mobile"`
	ProvinceId   int    `json:"province_id"`
	ProvinceName string `json:"province_name"`
	RealName     string `json:"real_name"`
	SellerId     int    `json:"seller_id"`
	UpdatedTime  int    `json:"updated_time"`
}
type DefaultRefundAddressRes struct {
	Address      string `json:"address"`
	CityId       int    `json:"city_id"`
	CreatedTime  int    `json:"created_time"`
	DistrictId   int    `json:"district_id"`
	DistrictName string `json:"district_name"`
	Id           int    `json:"id"`
	Info         string `json:"info"`
	IsDefault    int    `json:"is_default"`
	Mobile       string `json:"mobile"`
	RealName     string `json:"real_name"`
	SellerId     int    `json:"seller_id"`
	UpdatedTime  int    `json:"updated_time"`
}
